@@ -55,21 +55,37 @@ def exec_jar(source, max_days, dry_run):
 
     base_url = get_base_url()
 
+    # using subprocess.check_out with shell=False and a list of command to prevent vulnerability
+    # https://knowledge-base.secureflag.com/vulnerabilities/code_injection/os_command_injection_python.html
+    command = [java]
     https_proxy = os.getenv("HTTPS_PROXY")
     proxy_option = _build_proxy_option(https_proxy) if https_proxy else ""
+    if proxy_option != "":
+        command.append(proxy_option)
 
-    subprocess.check_output("{java} {proxy_option} -jar \"{jar_file_path}\" ingest:commit -endpoint {endpoint} -max-days {max_days} {audit} {scrub_pli} {dry_run} {source}"
-                            .format(
-                                java=java,
-                                proxy_option=proxy_option,
-                                jar_file_path=jar_file_path,
-                                endpoint="{}/intake/".format(base_url),
-                                max_days=max_days,
-                                audit="-audit" if Logger().logger.isEnabledFor(LOG_LEVEL_AUDIT) else "",
-                                scrub_pli="-scrub-pii",
-                                dry_run="-dry-run" if dry_run else "",
-                                source=source),
-                            shell=True)
+    command.extend(
+        [
+            "-jar",
+            jar_file_path,
+            "ingest:commit",
+            "-endpoint",
+            "{}/intake/".format(base_url),
+            "-max-days",
+            str(max_days),
+            "-scrub-pii",
+        ],
+    )
+
+    if Logger().logger.isEnabledFor(LOG_LEVEL_AUDIT):
+        command.append("-audit")
+    if dry_run:
+        command.append("-dry-run")
+    command.append(source)
+
+    subprocess.check_output(
+        command,
+        shell=False,
+    )
 
 
 def _build_proxy_option(https_proxy: str) -> str:
